@@ -86,8 +86,8 @@ MLFLOW_HTTP_REQUEST_BACKOFF_FACTOR = _EnvironmentVariable(
 MLFLOW_HTTP_REQUEST_TIMEOUT = _EnvironmentVariable("MLFLOW_HTTP_REQUEST_TIMEOUT", int, 120)
 
 #: Specifies whether MLFlow HTTP requests should be signed using AWS signature V4. It will overwrite
-#: (default: ``False``). When set, it will overwrite the "Authorization" HTTP header
-# See https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html for more information.
+#: (default: ``False``). When set, it will overwrite the "Authorization" HTTP header.
+#: See https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html for more information.
 MLFLOW_TRACKING_AWS_SIGV4 = _BooleanEnvironmentVariable("MLFLOW_TRACKING_AWS_SIGV4", False)
 
 #: Specifies the chunk size to use when downloading a file from GCS
@@ -100,6 +100,7 @@ MLFLOW_GCS_DOWNLOAD_CHUNK_SIZE = _EnvironmentVariable("MLFLOW_GCS_DOWNLOAD_CHUNK
 #: ``google-cloud-storage`` package.
 MLFLOW_GCS_UPLOAD_CHUNK_SIZE = _EnvironmentVariable("MLFLOW_GCS_UPLOAD_CHUNK_SIZE", int, None)
 
+#: (Deprecated, please use ``MLFLOW_ARTIFACT_UPLOAD_DOWNLOAD_TIMEOUT``)
 #: Specifies the default timeout to use when downloading/uploading a file from/to GCS
 #: (default: ``None``). If None, ``google.cloud.storage.constants._DEFAULT_TIMEOUT`` is used.
 MLFLOW_GCS_DEFAULT_TIMEOUT = _EnvironmentVariable("MLFLOW_GCS_DEFAULT_TIMEOUT", int, None)
@@ -162,6 +163,11 @@ MLFLOW_SQLALCHEMYSTORE_MAX_OVERFLOW = _EnvironmentVariable(
 #: (default: ``False``)
 MLFLOW_SQLALCHEMYSTORE_ECHO = _BooleanEnvironmentVariable("MLFLOW_SQLALCHEMYSTORE_ECHO", False)
 
+#: Specifies whether or not to print a warning when `--env-manager=conda` is specified.
+#: (default: ``False``)
+MLFLOW_DISABLE_ENV_MANAGER_CONDA_WARNING = _BooleanEnvironmentVariable(
+    "MLFLOW_DISABLE_ENV_MANAGER_CONDA_WARNING", False
+)
 #: Specifies the ``poolclass`` parameter to use for ``sqlalchemy.create_engine`` in the
 #: SQLAlchemy tracking store. See https://docs.sqlalchemy.org/en/14/core/engines.html#sqlalchemy.create_engine.params.poolclass
 #: for more information.
@@ -176,10 +182,23 @@ MLFLOW_REQUIREMENTS_INFERENCE_TIMEOUT = _EnvironmentVariable(
     "MLFLOW_REQUIREMENTS_INFERENCE_TIMEOUT", int, 120
 )
 
-#: Specifies whether or not to allow using a file URI as a model version source.
-#: Please be aware that setting this environment variable to True is potentially risky
-#: because it can allow access to arbitrary files on the specified filesystem
-#: (default: ``False``).
-MLFLOW_ALLOW_FILE_URI_AS_MODEL_VERSION_SOURCE = _BooleanEnvironmentVariable(
-    "MLFLOW_ALLOW_FILE_URI_AS_MODEL_VERSION_SOURCE", False
+#: Specifies the MLflow Model Scoring server request timeout in seconds
+#: (default: ``60``)
+MLFLOW_SCORING_SERVER_REQUEST_TIMEOUT = _EnvironmentVariable(
+    "MLFLOW_SCORING_SERVER_REQUEST_TIMEOUT", int, 60
+)
+
+#: (Experimental, may be changed or removed)
+#: Specifies the timeout to use when uploading or downloading a file
+#: (default: ``None``). If None, individual artifact stores will choose defaults.
+MLFLOW_ARTIFACT_UPLOAD_DOWNLOAD_TIMEOUT = _EnvironmentVariable(
+    "MLFLOW_ARTIFACT_UPLOAD_DOWNLOAD_TIMEOUT", int, None
+)
+
+#: Specifies the device intended for use in the predict function - can be used
+#: to override behavior where the GPU is used by default when available by
+#: setting this environment variable to be ``cpu``. Currently, this
+#: variable is only supported for the MLflow PyTorch flavor.
+MLFLOW_DEFAULT_PREDICTION_DEVICE = _EnvironmentVariable(
+    "MLFLOW_DEFAULT_PREDICTION_DEVICE", str, None
 )
