@@ -1,7 +1,9 @@
 from abc import abstractmethod, ABCMeta
+from mlflow.utils.annotations import developer_stable
 
 
-class AbstractBackend():
+@developer_stable
+class AbstractBackend:
     """
     Abstract plugin class defining the interface needed to execute MLflow projects. You can define
     subclasses of ``AbstractBackend`` and expose them as third-party plugins to enable running
@@ -9,11 +11,20 @@ class AbstractBackend():
     in-house cluster or job scheduler). See `MLflow Plugins <../../plugins.html>`_ for more
     information.
     """
+
     __metaclass__ = ABCMeta
 
     @abstractmethod
-    def run(self, project_uri, entry_point, params,
-            version, backend_config, tracking_uri, experiment_id):
+    def run(
+        self,
+        project_uri,
+        entry_point,
+        params,
+        version,
+        backend_config,
+        tracking_uri,
+        experiment_id,
+    ):
         """
         Submit an entrypoint. It must return a SubmittedRun object to track the execution
 
