@@ -6,6 +6,7 @@ import sys
 from functools import partial
 import numpy as np
 import pandas as pd
+from enum import Enum
 from multiprocessing.pool import ThreadPool, Pool
 
 from mlflow.recipes.artifacts import DataframeArtifact
@@ -30,6 +31,19 @@ _USER_DEFINED_SPLIT_STEP_MODULE = "steps.split"
 _MAX_CLASSES_TO_PROFILE = 5
 
 
+class SplitValues(Enum):
+    """
+    Represents the custom split return values.
+    """
+
+    # Indicates that the row is part of test split
+    TEST = "TEST"
+    # Indicates that the row is part of train split
+    TRAINING = "TRAINING"
+    # Indicates that the row is part of validation split
+    VALIDATION = "VALIDATION"
+
+
 def _make_elem_hashable(elem):
     if isinstance(elem, list):
         return tuple(_make_elem_hashable(e) for e in elem)
@@ -59,8 +73,8 @@ def _perform_stratified_split_per_class(input_df, split_ratios, target_col):
 
     with ThreadPool(os.cpu_count() or _NUM_DEFAULT_CPUS) as p:
         zipped_dfs = p.map(partial_func, classes)
-        test_df, train_df, validation_df = [pd.concat(x) for x in list(zip(*zipped_dfs))]
-        return test_df, train_df, validation_df
+        train_df, validation_df, test_df = [pd.concat(x) for x in list(zip(*zipped_dfs))]
+        return train_df, validation_df, test_df
 
 
 def _perform_split_for_one_class(
@@ -76,7 +90,7 @@ def _perform_split_for_one_class(
 def _perform_split(input_df, split_ratios, n_jobs=-1):
     hash_buckets = _create_hash_buckets(input_df, n_jobs=n_jobs)
     train_df, validation_df, test_df = _get_split_df(input_df, hash_buckets, split_ratios)
-    return test_df, train_df, validation_df
+    return train_df, validation_df, test_df
 
 
 def _get_split_df(input_df, hash_buckets, split_ratios):
@@ -159,7 +173,7 @@ def _validate_user_code_output(post_split, train_df, validation_df, test_df):
             " Expected output is a tuple with (train_df, validation_df, test_df)"
         ) from None
 
-    for (post_split_df, pre_split_df, split_type) in [
+    for post_split_df, pre_split_df, split_type in [
         [post_filter_train_df, train_df, "train"],
         [post_filter_validation_df, validation_df, "validation"],
         [post_filter_test_df, test_df, "test"],
@@ -199,14 +213,32 @@ class SplitStep(BaseStep):
             )
         self.skip_data_profiling = self.step_config.get("skip_data_profiling", False)
 
-        self.split_ratios = self.step_config.get("split_ratios", [0.75, 0.125, 0.125])
-        if not (
-            isinstance(self.split_ratios, list)
-            and len(self.split_ratios) == 3
-            and all(isinstance(x, (int, float)) and x > 0 for x in self.split_ratios)
-        ):
+        if "using" in self.step_config:
+            if self.step_config["using"] not in ["custom", "split_ratios"]:
+                raise MlflowException(
+                    f"Invalid split step configuration value {self.step_config['using']} for "
+                    f"key 'using'. Supported values are: ['custom', 'split_ratios']",
+                    error_code=INVALID_PARAMETER_VALUE,
+                )
+        else:
+            self.step_config["using"] = "split_ratios"
+
+        if self.step_config["using"] == "split_ratios":
+            self.split_ratios = self.step_config.get("split_ratios", [0.75, 0.125, 0.125])
+            if not (
+                isinstance(self.split_ratios, list)
+                and len(self.split_ratios) == 3
+                and all(isinstance(x, (int, float)) and x > 0 for x in self.split_ratios)
+            ):
+                raise MlflowException(
+                    "Config split_ratios must be a list containing 3 positive numbers."
+                )
+
+        if "split_method" not in self.step_config and self.step_config["using"] == "custom":
             raise MlflowException(
-                "Config split_ratios must be a list containing 3 positive numbers."
+                "Missing 'split_method' configuration in the split step, "
+                "which is using 'custom'.",
+                error_code=INVALID_PARAMETER_VALUE,
             )
 
     def _build_profiles_and_card(self, train_df, validation_df, test_df) -> BaseCard:
@@ -307,6 +339,48 @@ class SplitStep(BaseStep):
 
         return card
 
+    def _validate_and_execute_custom_split(self, split_fn, input_df):
+        custom_split_mapping_series = split_fn(input_df)
+        if not isinstance(custom_split_mapping_series, pd.Series):
+            raise MlflowException(
+                "Return type of the custom split function should be a pandas series",
+                error_code=INVALID_PARAMETER_VALUE,
+            )
+
+        copy_df = input_df.copy()
+        copy_df["split"] = custom_split_mapping_series
+        train_df = input_df[copy_df["split"] == SplitValues.TRAINING.value].reset_index(drop=True)
+        validation_df = input_df[copy_df["split"] == SplitValues.VALIDATION.value].reset_index(
+            drop=True
+        )
+        test_df = input_df[copy_df["split"] == SplitValues.TEST.value].reset_index(drop=True)
+
+        if train_df.size + validation_df.size + test_df.size != input_df.size:
+            incorrect_args = custom_split_mapping_series[
+                ~custom_split_mapping_series.isin(
+                    [
+                        SplitValues.TRAINING.value,
+                        SplitValues.VALIDATION.value,
+                        SplitValues.TEST.value,
+                    ]
+                )
+            ].unique()
+            raise MlflowException(
+                f"Returned pandas series from custom split step should only contain "
+                f"{SplitValues.TRAINING.value}, {SplitValues.VALIDATION.value} or "
+                f"{SplitValues.TEST.value} as values. Value returned back: {incorrect_args}",
+                error_code=INVALID_PARAMETER_VALUE,
+            )
+
+        return train_df, validation_df, test_df
+
+    def _run_custom_split(self, input_df):
+        split_fn = getattr(
+            importlib.import_module(_USER_DEFINED_SPLIT_STEP_MODULE),
+            self.step_config["split_method"],
+        )
+        return self._validate_and_execute_custom_split(split_fn, input_df)
+
     def _run(self, output_directory):
         run_start_time = time.time()
 
@@ -331,9 +405,12 @@ class SplitStep(BaseStep):
         self.num_dropped_rows = raw_input_num_rows - len(input_df)
 
         # split dataset
-        test_df, train_df, validation_df = _run_split(
-            self.task, input_df, self.split_ratios, self.target_col
-        )
+        if self.step_config["using"] == "custom":
+            train_df, validation_df, test_df = self._run_custom_split(input_df)
+        else:
+            train_df, validation_df, test_df = _run_split(
+                self.task, input_df, self.split_ratios, self.target_col
+            )
         # Import from user function module to process dataframes
         post_split_config = self.step_config.get("post_split_method", None)
         post_split_filter_config = self.step_config.get("post_split_filter_method", None)
