@@ -17,6 +17,7 @@ from mlflow.entities.model_registry.model_version_stages import (
     DEFAULT_STAGES_FOR_GET_LATEST_VERSIONS,
     STAGE_ARCHIVED,
     STAGE_NONE,
+    STAGE_DELETED_INTERNAL,
 )
 from mlflow.exceptions import MlflowException
 from mlflow.protos.databricks_pb2 import (
@@ -29,13 +30,14 @@ from mlflow.store.model_registry.abstract_store import AbstractStore
 from mlflow.store.model_registry import (
     DEFAULT_LOCAL_FILE_AND_ARTIFACT_PATH,
     SEARCH_REGISTERED_MODEL_MAX_RESULTS_THRESHOLD,
+    SEARCH_MODEL_VERSION_MAX_RESULTS_THRESHOLD,
 )
 from mlflow.utils.search_utils import SearchUtils, SearchModelUtils, SearchModelVersionUtils
 from mlflow.utils.string_utils import is_string_type
 from mlflow.utils.validation import (
     _validate_registered_model_tag,
     _validate_model_version_tag,
-    _validate_model_name,
+    _validate_model_name as _original_validate_model_name,
     _validate_model_version,
     _validate_tag_name,
 )
@@ -54,11 +56,9 @@ from mlflow.utils.file_utils import (
     make_containing_dirs,
     list_all,
     local_file_uri_to_path,
+    contains_path_separator,
 )
-
-
-def now():
-    return int(time.time() * 1000)
+from mlflow.utils.time_utils import get_current_time_millis
 
 
 _REGISTRY_DIR_ENV_VAR = "MLFLOW_REGISTRY_DIR"
@@ -68,6 +68,15 @@ def _default_root_dir():
     return get_env(_REGISTRY_DIR_ENV_VAR) or os.path.abspath(DEFAULT_LOCAL_FILE_AND_ARTIFACT_PATH)
 
 
+def _validate_model_name(name):
+    _original_validate_model_name(name)
+    if contains_path_separator(name):
+        raise MlflowException(
+            f"Invalid name: '{name}'. Registered model name cannot contain path separator",
+            INVALID_PARAMETER_VALUE,
+        )
+
+
 class FileStore(AbstractStore):
     MODELS_FOLDER_NAME = "models"
     META_DATA_FILE_NAME = "meta.yaml"
@@ -150,7 +159,7 @@ class FileStore(AbstractStore):
             _validate_registered_model_tag(tag.key, tag.value)
         meta_dir = self._get_registered_model_path(name)
         mkdir(meta_dir)
-        creation_time = now()
+        creation_time = get_current_time_millis()
         latest_versions = []
         registered_model = RegisteredModel(
             name=name,
@@ -189,7 +198,7 @@ class FileStore(AbstractStore):
         :return: A single updated :py:class:`mlflow.entities.model_registry.RegisteredModel` object.
         """
         registered_model = self.get_registered_model(name)
-        updated_time = now()
+        updated_time = get_current_time_millis()
         registered_model.description = description
         registered_model.last_updated_timestamp = updated_time
         self._save_registered_model_as_meta_file(registered_model)
@@ -206,7 +215,7 @@ class FileStore(AbstractStore):
         model_path = self._get_registered_model_path(name)
         if not exists(model_path):
             raise MlflowException(
-                f"Could not find registered model with name {name}",
+                f"Registered Model with name={name} not found",
                 RESOURCE_DOES_NOT_EXIST,
             )
         registered_model = self._get_registered_model_from_path(model_path)
@@ -214,7 +223,7 @@ class FileStore(AbstractStore):
         new_meta_dir = self._get_registered_model_path(new_name)
         if not exists(new_meta_dir):
             mkdir(new_meta_dir)
-            updated_time = now()
+            updated_time = get_current_time_millis()
             registered_model.name = new_name
             registered_model.last_updated_timestamp = updated_time
             self._save_registered_model_as_meta_file(
@@ -239,6 +248,8 @@ class FileStore(AbstractStore):
                 RESOURCE_ALREADY_EXISTS,
             )
 
+        return registered_model
+
     def delete_registered_model(self, name):
         """
         Delete the registered model.
@@ -250,7 +261,7 @@ class FileStore(AbstractStore):
         meta_dir = self._get_registered_model_path(name)
         if not exists(meta_dir):
             raise MlflowException(
-                f"Could not find registered model with name {name}",
+                f"Registered Model with name={name} not found",
                 RESOURCE_DOES_NOT_EXIST,
             )
         shutil.rmtree(meta_dir)
@@ -327,7 +338,7 @@ class FileStore(AbstractStore):
         model_path = self._get_registered_model_path(name)
         if not exists(model_path):
             raise MlflowException(
-                f"Could not find registered model with name {name}",
+                f"Registered Model with name={name} not found",
                 RESOURCE_DOES_NOT_EXIST,
             )
         return self._get_registered_model_from_path(model_path)
@@ -345,7 +356,7 @@ class FileStore(AbstractStore):
         registered_model_path = self._get_registered_model_path(name)
         if not exists(registered_model_path):
             raise MlflowException(
-                f"Could not find registered model with name {name}",
+                f"Registered Model with name={name} not found",
                 RESOURCE_DOES_NOT_EXIST,
             )
         model_versions = self._list_model_versions_under_path(registered_model_path)
@@ -370,7 +381,7 @@ class FileStore(AbstractStore):
         registered_model_path = self._get_registered_model_path(name)
         if not exists(registered_model_path):
             raise MlflowException(
-                f"Could not find registered model with name {name}",
+                f"Registered Model with name={name} not found",
                 RESOURCE_DOES_NOT_EXIST,
             )
         return os.path.join(registered_model_path, FileStore.TAGS_FOLDER_NAME, tag_name)
@@ -427,7 +438,7 @@ class FileStore(AbstractStore):
         tag_path = self._get_registered_model_tag_path(name, tag.key)
         make_containing_dirs(tag_path)
         write_to(tag_path, self._writeable_value(tag.value))
-        updated_time = now()
+        updated_time = get_current_time_millis()
         self._update_registered_model_last_updated_time(name, updated_time)
 
     def delete_registered_model_tag(self, name, key):
@@ -441,7 +452,7 @@ class FileStore(AbstractStore):
         tag_path = self._get_registered_model_tag_path(name, key)
         if exists(tag_path):
             os.remove(tag_path)
-            updated_time = now()
+            updated_time = get_current_time_millis()
             self._update_registered_model_last_updated_time(name, updated_time)
 
     # CRUD API for ModelVersion objects
@@ -462,7 +473,7 @@ class FileStore(AbstractStore):
         registered_model_path = self._get_registered_model_path(name)
         if not exists(registered_model_path):
             raise MlflowException(
-                f"Could not find registered model with name {name}",
+                f"Registered Model with name={name} not found",
                 RESOURCE_DOES_NOT_EXIST,
             )
         return join(registered_model_path, f"version-{version}")
@@ -509,9 +520,11 @@ class FileStore(AbstractStore):
                  created in the backend.
         """
 
-        def next_version(registered_model):
-            if registered_model.latest_versions:
-                return max([mv.version for mv in registered_model.latest_versions]) + 1
+        def next_version(registered_model_name):
+            path = self._get_registered_model_path(registered_model_name)
+            model_versions = self._list_model_versions_under_path(path)
+            if model_versions:
+                return max(mv.version for mv in model_versions) + 1
             else:
                 return 1
 
@@ -520,10 +533,11 @@ class FileStore(AbstractStore):
             _validate_model_version_tag(tag.key, tag.value)
         for attempt in range(self.CREATE_MODEL_VERSION_RETRIES):
             try:
-                creation_time = now()
+                creation_time = get_current_time_millis()
                 registered_model = self.get_registered_model(name)
                 registered_model.last_updated_timestamp = creation_time
-                version = next_version(registered_model)
+                self._save_registered_model_as_meta_file(registered_model)
+                version = next_version(name)
                 model_version = ModelVersion(
                     name=name,
                     version=version,
@@ -541,6 +555,7 @@ class FileStore(AbstractStore):
                 self._save_model_version_as_meta_file(
                     model_version, meta_dir=model_version_dir, overwrite=False
                 )
+                self._save_registered_model_as_meta_file(registered_model)
                 if tags is not None:
                     for tag in tags:
                         self.set_model_version_tag(name, version, tag)
@@ -568,12 +583,11 @@ class FileStore(AbstractStore):
         :param description: New model description.
         :return: A single :py:class:`mlflow.entities.model_registry.ModelVersion` object.
         """
-        updated_time = now()
+        updated_time = get_current_time_millis()
         model_version = self.get_model_version(name=name, version=version)
         model_version.description = description
         model_version.last_updated_timestamp = updated_time
         self._save_model_version_as_meta_file(model_version)
-        self._update_registered_model_last_updated_time(name, updated_time)
         return model_version
 
     def transition_model_version_stage(self, name, version, stage, archive_existing_versions):
@@ -597,7 +611,7 @@ class FileStore(AbstractStore):
             )
             raise MlflowException(msg_tpl.format(stage, DEFAULT_STAGES_FOR_GET_LATEST_VERSIONS))
 
-        last_updated_time = now()
+        last_updated_time = get_current_time_millis()
         model_versions = []
         if archive_existing_versions:
             registered_model_path = self._get_registered_model_path(name)
@@ -623,14 +637,11 @@ class FileStore(AbstractStore):
         :param version: Registered model version.
         :return: None
         """
-        meta_dir = self._get_model_version_dir(name, version)
-        if not exists(meta_dir):
-            raise MlflowException(
-                f"Model Version (name={name}, version={version}) not found",
-                RESOURCE_DOES_NOT_EXIST,
-            )
-        shutil.rmtree(meta_dir)
-        updated_time = now()
+        model_version = self.get_model_version(name=name, version=version)
+        model_version.current_stage = STAGE_DELETED_INTERNAL
+        updated_time = get_current_time_millis()
+        model_version.last_updated_timestamp = updated_time
+        self._save_model_version_as_meta_file(model_version)
         self._update_registered_model_last_updated_time(name, updated_time)
 
     def get_model_version(self, name, version):
@@ -650,6 +661,11 @@ class FileStore(AbstractStore):
                 RESOURCE_DOES_NOT_EXIST,
             )
         model_version = self._get_model_version_from_dir(registered_model_version_dir)
+        if model_version.current_stage == STAGE_DELETED_INTERNAL:
+            raise MlflowException(
+                f"Model Version (name={name}, version={version}) not found",
+                RESOURCE_DOES_NOT_EXIST,
+            )
         return model_version
 
     def get_model_version_download_uri(self, name, version):
@@ -684,24 +700,56 @@ class FileStore(AbstractStore):
             model_versions.append(self._get_model_version_from_dir(directory))
         return model_versions
 
-    def search_model_versions(self, filter_string):
+    def search_model_versions(
+        self, filter_string=None, max_results=None, order_by=None, page_token=None
+    ):
         """
         Search for model versions in backend that satisfy the filter criteria.
 
         :param filter_string: A filter string expression. Currently supports a single filter
                               condition either name of model like ``name = 'model_name'`` or
                               ``run_id = '...'``.
-        :return: PagedList of :py:class:`mlflow.entities.model_registry.ModelVersion`
-                 objects.
+        :param max_results: Maximum number of model versions desired.
+        :param order_by: List of column names with ASC|DESC annotation, to be used for ordering
+                         matching search results.
+        :param page_token: Token specifying the next page of results. It should be obtained from
+                            a ``search_model_versions`` call.
+        :return: A PagedList of :py:class:`mlflow.entities.model_registry.ModelVersion`
+                 objects that satisfy the search expressions. The pagination token for the next
+                 page can be obtained via the ``token`` attribute of the object.
         """
-        # should we filter name directly if the condition is about name?
-        # do all model versions under the same registered_model have the same name?
+        if not isinstance(max_results, int) or max_results < 1:
+            raise MlflowException(
+                "Invalid value for max_results. It must be a positive integer,"
+                f" but got {max_results}",
+                INVALID_PARAMETER_VALUE,
+            )
+
+        if max_results > SEARCH_MODEL_VERSION_MAX_RESULTS_THRESHOLD:
+            raise MlflowException(
+                "Invalid value for request parameter max_results. It must be at most "
+                f"{SEARCH_MODEL_VERSION_MAX_RESULTS_THRESHOLD}, but got value {max_results}",
+                INVALID_PARAMETER_VALUE,
+            )
+
         registered_model_paths = self._get_all_registered_model_paths()
         model_versions = []
         for path in registered_model_paths:
             model_versions.extend(self._list_model_versions_under_path(path))
         filtered_mvs = SearchModelVersionUtils.filter(model_versions, filter_string)
-        return PagedList(filtered_mvs, None)
+
+        sorted_mvs = SearchModelVersionUtils.sort(
+            filtered_mvs,
+            order_by or ["last_updated_timestamp DESC", "name ASC", "version_number DESC"],
+        )
+        start_offset = SearchUtils.parse_start_offset_from_page_token(page_token)
+        final_offset = start_offset + max_results
+
+        paginated_mvs = sorted_mvs[start_offset:final_offset]
+        next_page_token = None
+        if final_offset < len(sorted_mvs):
+            next_page_token = SearchUtils.create_page_token(final_offset)
+        return PagedList(paginated_mvs, next_page_token)
 
     def _get_registered_model_version_tag_path(self, name, version, tag_name):
         _validate_model_name(name)
@@ -713,6 +761,12 @@ class FileStore(AbstractStore):
                 f"Model Version (name={name}, version={version}) not found",
                 RESOURCE_DOES_NOT_EXIST,
             )
+        model_version = self._get_model_version_from_dir(registered_model_version_path)
+        if model_version.current_stage == STAGE_DELETED_INTERNAL:
+            raise MlflowException(
+                f"Model Version (name={name}, version={version}) not found",
+                RESOURCE_DOES_NOT_EXIST,
+            )
         return os.path.join(registered_model_version_path, FileStore.TAGS_FOLDER_NAME, tag_name)
 
     def set_model_version_tag(self, name, version, tag):
@@ -728,7 +782,7 @@ class FileStore(AbstractStore):
         tag_path = self._get_registered_model_version_tag_path(name, version, tag.key)
         make_containing_dirs(tag_path)
         write_to(tag_path, self._writeable_value(tag.value))
-        updated_time = now()
+        updated_time = get_current_time_millis()
         self._update_registered_model_last_updated_time(name, updated_time)
 
     def delete_model_version_tag(self, name, version, key):
@@ -743,7 +797,7 @@ class FileStore(AbstractStore):
         tag_path = self._get_registered_model_version_tag_path(name, version, key)
         if exists(tag_path):
             os.remove(tag_path)
-            updated_time = now()
+            updated_time = get_current_time_millis()
             self._update_registered_model_last_updated_time(name, updated_time)
 
     @staticmethod
