@@ -76,7 +76,10 @@ from mlflow.utils.file_utils import (
 from mlflow.utils.search_utils import SearchUtils, SearchExperimentsUtils
 from mlflow.utils.string_utils import is_string_type
 from mlflow.utils.time_utils import get_current_time_millis
-from mlflow.utils.uri import append_to_uri_path
+from mlflow.utils.uri import (
+    append_to_uri_path,
+    resolve_uri_if_local,
+)
 from mlflow.utils.mlflow_tags import MLFLOW_LOGGED_MODELS, MLFLOW_RUN_NAME, _get_run_name_from_tags
 
 _TRACKING_DIR_ENV_VAR = "MLFLOW_TRACKING_DIR"
@@ -147,7 +150,10 @@ class FileStore(AbstractStore):
         """
         super().__init__()
         self.root_directory = local_file_uri_to_path(root_directory or _default_root_dir())
-        self.artifact_root_uri = artifact_root_uri or path_to_local_file_uri(self.root_directory)
+        if not artifact_root_uri:
+            self.artifact_root_uri = path_to_local_file_uri(self.root_directory)
+        else:
+            self.artifact_root_uri = resolve_uri_if_local(artifact_root_uri)
         self.trash_folder = os.path.join(self.root_directory, FileStore.TRASH_FOLDER_NAME)
         # Create root directory if needed
         if not exists(self.root_directory):
@@ -257,7 +263,6 @@ class FileStore(AbstractStore):
         order_by=None,
         page_token=None,
     ):
-
         if not isinstance(max_results, int) or max_results < 1:
             raise MlflowException(
                 "Invalid value for max_results. It must be a positive integer,"
@@ -315,16 +320,16 @@ class FileStore(AbstractStore):
         return experiments[0] if len(experiments) > 0 else None
 
     def _create_experiment_with_id(self, name, experiment_id, artifact_uri, tags):
-        artifact_uri = artifact_uri or append_to_uri_path(
-            self.artifact_root_uri, str(experiment_id)
-        )
-        self._check_root_dir()
+        if not artifact_uri:
+            resolved_artifact_uri = append_to_uri_path(self.artifact_root_uri, str(experiment_id))
+        else:
+            resolved_artifact_uri = resolve_uri_if_local(artifact_uri)
         meta_dir = mkdir(self.root_directory, str(experiment_id))
         creation_time = get_current_time_millis()
         experiment = Experiment(
             experiment_id,
             name,
-            artifact_uri,
+            resolved_artifact_uri,
             LifecycleStage.ACTIVE,
             creation_time=creation_time,
             last_update_time=creation_time,
@@ -773,11 +778,7 @@ class FileStore(AbstractStore):
 
         parent_path, metric_files = self._get_run_files(run_info, "metric")
         if metric_key not in metric_files:
-            run_id = run_info.run_id
-            raise MlflowException(
-                f"Metric '{metric_key}' not found under run '{run_id}'",
-                databricks_pb2.RESOURCE_DOES_NOT_EXIST,
-            )
+            return PagedList([], None)
         return PagedList(
             [
                 FileStore._get_metric_from_line(metric_key, line)
@@ -961,7 +962,7 @@ class FileStore(AbstractStore):
         experiment = self.get_experiment(experiment_id)
         if experiment.lifecycle_stage != LifecycleStage.ACTIVE:
             raise MlflowException(
-                "The experiment {} must be in the 'active'"
+                "The experiment {} must be in the 'active' "
                 "lifecycle_stage to set tags".format(experiment.experiment_id),
                 error_code=databricks_pb2.INVALID_PARAMETER_VALUE,
             )
