@@ -38,7 +38,7 @@ def _get_tensor_shape(data, variable_dimension: Optional[int] = 0) -> tuple:
             variable_input_data_shape[variable_dimension] = -1
         except IndexError:
             raise MlflowException(
-                "The specified variable_dimension {} is out of bounds with"
+                "The specified variable_dimension {} is out of bounds with "
                 "respect to the number of dimensions {} in the input dataset".format(
                     variable_dimension, data.ndim
                 )
@@ -138,9 +138,15 @@ def _infer_schema(data: Any) -> Schema:
         )
     else:
         raise TypeError(
-            "Expected one of (pandas.DataFrame, numpy array, "
-            "dictionary of (name -> numpy.ndarray), pyspark.sql.DataFrame) "
-            "but got '{}'".format(type(data))
+            "Expected one of the following types:\n"
+            "- pandas.DataFrame\n"
+            "- pandas.Series\n"
+            "- numpy.ndarray\n"
+            "- dictionary of (name -> numpy.ndarray)\n"
+            "- pyspark.sql.DataFrame\n",
+            "- scipy.sparse.csr_matrix\n"
+            "- scipy.sparse.csc_matrix\n"
+            "but got '{}'".format(type(data)),
         )
     if not schema.is_tensor_spec() and any(
         t in (DataType.integer, DataType.long) for t in schema.input_types()
@@ -235,7 +241,7 @@ def _infer_pandas_column(col: pd.Series) -> DataType:
             return DataType.string
         else:
             raise MlflowException(
-                "Unable to map 'object' type to MLflow DataType. object can"
+                "Unable to map 'object' type to MLflow DataType. object can "
                 "be mapped iff all values have identical data type which is one "
                 "of (string, (bytes or byterray),  int, float)."
             )
