@@ -1,8 +1,32 @@
 import random
+import uuid
+
+_EXPERIMENT_ID_FIXED_WIDTH = 18
+
+
+def _generate_unique_integer_id():
+    """
+    Utility function for generating a random fixed-length integer
+    :param id_length: The target length of the string representation of the integer without
+                      leading zeros
+    :return: a fixed-width integer
+    """
+
+    random_int = uuid.uuid4().int
+    # Cast to string to get a fixed length
+    random_str = str(random_int)[-_EXPERIMENT_ID_FIXED_WIDTH:]
+    # append a random int as string to the end of the generated string for as many
+    # leading zeros exist in the generated string in order to preserve the total length
+    # once cast back to int
+    for s in random_str:
+        if s == "0":
+            random_str = random_str + str(random.randint(0, 9))
+        else:
+            break
+    return int(random_str)
 
 
 def _generate_string(sep, integer_scale):
-
     predicate = random.choice(_GENERATOR_PREDICATES).lower()
     noun = random.choice(_GENERATOR_NOUNS).lower()
     num = random.randint(0, 10**integer_scale)
@@ -12,7 +36,7 @@ def _generate_string(sep, integer_scale):
 def _generate_random_name(sep="-", integer_scale=3, max_length=20):
     """Helper function for generating a random predicate, noun, and integer combination
 
-    :param sep: String seperator for word spacing
+    :param sep: String separator for word spacing
     :param integer_scale: dictates the maximum scale range for random integer sampling (power of 10)
     :param max_length: maximum allowable string length
 
