@@ -1,6 +1,7 @@
 from .pytest_raises_checker import PytestRaisesChecker
 from .print_function import PrintFunction
 from .unittest_assert_raises import UnittestAssertRaises
+from .string_checker import StringChecker
 from .set_checker import SetChecker
 
 
@@ -9,3 +10,4 @@ def register(linter):
     linter.register_checker(PrintFunction(linter))
     linter.register_checker(UnittestAssertRaises(linter))
     linter.register_checker(SetChecker(linter))
+    linter.register_checker(StringChecker(linter))
